#include <VRS51L3074_SDCC.h>



void initAD(void)
{
int cptr = 0x00;
char readflag = 0x00;

	PERIPHEN1 |= 0xC0; 				//Make sure the SPI Interface is activated
	//--Wait activity stops on the SPI interface (Monitor SPINOCS)
	while(!(SPISTATUS &= 0x08));
	SPICTRL = 0x85;				//SPICLK = /32 (1.25MHz)
								//CS0 Active
								//SPI Mode 0 Phase = 0, POL = 0
								//SPI Master Mode

	SPICONFIG = 0x42;				//SPI Chip select is automatic
								//Clear SPIUNDEFC Flag
								//SPILOAD = 0 -> Manual CS3 behaviour
								//RXAV Interrupt used

	SPISTATUS = 0x00;				//SPI transactions are in MSB First Format

	SPISIZE = 0x17;				        //SPI Transaction Size is 24-bits
	//-Dummy Read the SPI RX buffer to clear the RXAV Flag
	readflag = SPIRXTX0;
        INTSRC1 &= ~(1<<2);                   // SPI RXAV module interrupt
        INTEN1 |= (1<<2);                    // Enable SPI RXAV interrupt
}

void initPWM(void)
{
int cptr = 0x00;
char readflag = 0x00;

     PERIPHEN2 |= (1<<1); 		// Enable PWM SFRs (PWMSFREN)
     DEVIOMAP |= (1<<6);                // Enable alternate mapping (we use P5.5)
     //CLEAR All PWM Channels
     PWMCFG = 0x20;
     // Configure the PWM prescaler
     PWMCLKCFG = 0x00;                  // no clock prescaler
     // Configure PWM Polarity
     PWMLDPOL = (1<<5);                 // Set PWM5 in inverted polarity, so PWMMID data equals pulse width
                                        // PWM output = 1 until
                                        // PWMMID Value is reached
     //Configure PWM5 END value = 0x0FF (8bit)
     PWMCFG = 0x5D;                     // Point to PWM5 END MSB
     PWMDATA = 0x00;                    // Set Max Count MSB = 0x03
     PWMCFG = 0x4D;                     // Point to PWM5 END LSB
     PWMDATA = 0xFF;                    // Set Max Count = 0xFF
     //Configure PWM5 MID value for off state
     PWMCFG = 0x55;                     // Point to PWM5 MID MSB
     PWMDATA = 0x00;                    // Set PWM MID MSB = 0x00
     PWMCFG = 0x45;                     // Point to PWM5 MID LSB
     PWMDATA = 0x01;                    // Set PWM MID LSB = 0x00
     //Configure PWM4 END value = 0x03FF (10bit)
     PWMCFG = 0x54;                     // Point to PWM4 MID MSB
     PWMDATA = 0x03;                    // Set Max Count MSB = 0x03
     PWMCFG = 0x44;                     // Point to PWM4 MID LSB
     PWMDATA = 0xFF;                    // Set Max Count = 0xFF

     //--Configure and enable PWM4-7 as timer interrupt
     INTSRC2 &= ~(1<<5);                   // PWM7:4 Timer module interrupt
//     IPINSENS1 &= ~(1<<5);                // sensitive on high level(0)
//     IPININV1 &= ~(1<<5);                 // Set INT0 Pin sensitivity on normal level(0)
     INTEN2 |= (1<<5);                    // Enable PWM7:4 timer module interrupt
     INTPRI2 |= (1<<5);                    // Raise PWM7:4 timer module interrupt priority

     PWMTMREN = (1<<4);                 // Use PWM4 as timer
     PWMEN = (1<<5)|(1<<4);             // Enable PWM5 and PWM4

     PWMCFG &= 0x1F;                    // Clear the PWMWAIT bit to initiate
                                        // the PWMs operation
}

#define START	(1<<2)
#define SINGLE	(1<<1)
#define CHANNEL 3

void PWMTMRInterrupt(void) interrupt 13
{
        // we only use 1 int, otherwise should check which one (PWM4-7) is interrupting
P2|=(1<<2);
        __asm
        push _DEVMEMCFG
        push psw
        mov psw,#0x00
        __endasm;
        DEVMEMCFG&=~(1<<0);
        PWMTMRF &= ~(1<<4); //Clear the PWM Timer 4 OV Flag
	//-Perform the SPI read
	SPIRXTX2 = 0x00;			
	SPIRXTX1 = (CHANNEL<<6);
	SPIRXTX0 = START | SINGLE | (CHANNEL>>2);	//Writing to the SPIRXTX0 will trigger the SPI Transaction
        __asm
        pop psw
        pop _DEVMEMCFG
        __endasm;
P2&=~(1<<2);
}

